@@ -427,7 +427,7 @@ class NISQ_Shots:
         return np.random.multinomial(self.n_shots, row_prob)
 
     def measurement_array(self, dm=None):
-        n_proj = self.projectors.reshape(1, 2**self._qs, 2**self._qs)
+        n_proj = self.projectors.reshape(-1, 2**self._qs, 2**self._qs)
         dm = dm.reshape(1, 2**self._qs, 2**self._qs)
         ideal_tomo_list = self.get_tomo_from_density_matrix(dm, n_proj)
         ideal_tomo_array = np.array(ideal_tomo_list).reshape(-1, 2 ** self._qs)
